@@ -34,22 +34,22 @@ NULL
 };
 
 static char *TRANS_TEAM_LIST[] = {
-"[bg] Yasen Pramatarov <yasen@lindeas.com>",
 "[ca] Carles Tubio Terrón <c@rles-tub.io>",
 "[cs] David Vachulka <david@konstrukce-cad.com>",
 "[de] Thomas Bellmann <ThomasBellmann@gmx.net>",
 "[en_GB] Paul Mangan <paul@claws-mail.org>",
-"[eo] Sian Mountbatten <poenikatu@fastmail.co.uk>",
 "[es] Ricardo Mones Lastra <ricardo@mones.org>",
 "     Carles Tubio Terrón <c@rles-tub.io>",
 "[fi] Flammie Pirinen <flammie@iki.fi>",
 "[fr] Tristan Chabredier <wwp@claws-mail.org>",
 "[he] Isratine Citizen <genghiskhan@gmx.ca>",
 "[hu] Páder Rezső <rezso@rezso.net>",
+"[it] Luigi Votta <luigi.vtt@gmail.com>",
 "[lt] Mindaugas Baranauskas <embar@super.lt>",
 "[nb] Petter Adsen <petter@synth.no>",
 "[nl] Marcel Pol <mpol@gmx.net>",
 "[pt_BR] Frederico Goncalves Guimaraes <frederico@teia.bio.br>",
+"[ru] Mikhail Kurinnoi <viewizard@viewizard.com>",
 "[sk] Slavko <slavino@slavino.sk>",
 "[sv] Andreas Rönnquist <gusnan@openmailbox.org>",
 "[zh_TW] Mark Chang <mark.cyj@gmail.com>",
@@ -86,14 +86,16 @@ static char *CONTRIBS_LIST[] = {
 "André Filipe de Assunção e Brito",
 "Sergei Astanin",
 "Ruslan N. Balkin",
+"Andy Balaam",
 "Henri Bauer",
+"Didier Barvaux",
 "Fabio Júnior Beneditto",
 "M. Benkmann",
 "Wilbert Berendsen",
-"Didier Barvaux",
 "Sébastien Bigaret",
 "Laurent Bigonville",
 "Jean-Luc Biord",
+"Blatinox",
 "Pavlo Bohmat",
 "H. Merijn Brand",
 "Eugene Brevdo",
@@ -162,6 +164,8 @@ static char *CONTRIBS_LIST[] = {
 "Shawn Houston",
 "Michael Hughes",
 "Richard Hughes",
+"Arthur Huillet",
+"Ben Hutchings",
 "Chideok Hwang",
 "John E.P. Hynes",
 "Hironori IWANE",
@@ -171,6 +175,7 @@ static char *CONTRIBS_LIST[] = {
 "Mathias Intemann",
 "Ishihara",
 "Jens Jahnke",
+"Daniel Jakots",
 "Pascal Jermini",
 "KAJIWARA",
 "KUROSAWA",
@@ -181,6 +186,7 @@ static char *CONTRIBS_LIST[] = {
 "Fabian Keil",
 "Martin Kluge",
 "IWAMOTO Kouichi",
+"Mikhail Kurinnoi",
 "Abhay S. Kushwaha",
 "Joshua M. Kwan",
 "Jean-Yves Lefort",
